==> invenio_requests-0.3.14-py2.py3-none-any.whl: invenio_requests/assets/semantic-ui/js/invenio_requests/components/TimelineActionEvent.js <==
// This file is part of InvenioRequests
// Copyright (C) 2022 CERN.
//
// Invenio RDM Records is free software; you can redistribute it and/or modify it
// under the terms of the MIT License; see LICENSE file for more details.

import React, { Component } from "react";
import { Feed } from "semantic-ui-react";
import { TimelineEventBody } from "./TimelineEventBody";
import { Image } from "react-invenio-forms";
import PropTypes from "prop-types";
import Overridable from "react-overridable";
import RequestsFeed from "./RequestsFeed";
import { timestampToRelativeTime } from "../timelineEvents/utils";

class TimelineActionEvent extends Component {
  render() {
    const { event, iconName, iconColor, userAction, eventContent } = this.props;

    return (
      <Overridable
        id="TimelineActionEvent.layout"
        event={event}
        iconName={iconName}
        iconColor={iconColor}
        userAction={userAction}
      >
        <RequestsFeed.Item>
          <RequestsFeed.Content isEvent={true}>
            <RequestsFeed.Icon name={iconName} size="large" color={iconColor} />
            <RequestsFeed.Event isActionEvent={true}>
              <Feed.Label>
                {userAction && (
                  <Image
                    src="/static/images/square-placeholder.png"
                    as={Image}
                    avatar
                  />
                )}
              </Feed.Label>
              <Feed.Content>
                <Feed.Summary>
                  {userAction && (
                    <Feed.User as="a">{event.created_by?.user}</Feed.User>
                  )}{" "}
                  <TimelineEventBody
                    content={eventContent}
                    format={event?.payload?.format}
                  />
                  <Feed.Date>
                    {timestampToRelativeTime(event.created)}
                  </Feed.Date>
                </Feed.Summary>
              </Feed.Content>
            </RequestsFeed.Event>
          </RequestsFeed.Content>
        </RequestsFeed.Item>
      </Overridable>
    );
  }
}

TimelineActionEvent.propTypes = {
  event: PropTypes.object.isRequired,
  iconName: PropTypes.string.isRequired,
  eventContent: PropTypes.string.isRequired,
  iconColor: PropTypes.string,
  userAction: PropTypes.bool,
};

TimelineActionEvent.defaultProps = {
  iconColor: "grey",
  userAction: true,
};

export default Overridable.component(
  "TimelineActionEvent",
  TimelineActionEvent
);

==> invenio_requests-0.3.16-py2.py3-none-any.whl: invenio_requests/assets/semantic-ui/js/invenio_requests/components/TimelineActionEvent.js <==
// This file is part of InvenioRequests
// Copyright (C) 2022 CERN.
//
// Invenio RDM Records is free software; you can redistribute it and/or modify it
// under the terms of the MIT License; see LICENSE file for more details.

import PropTypes from "prop-types";
import React, { Component } from "react";
import { Image } from "react-invenio-forms";
import Overridable from "react-overridable";
import { Feed } from "semantic-ui-react";
import { timestampToRelativeTime } from "../utils";
import RequestsFeed from "./RequestsFeed";
import { TimelineEventBody } from "./TimelineEventBody";

class TimelineActionEvent extends Component {
  render() {
    const { event, iconName, iconColor, eventContent } = this.props;

    const createdBy = event.created_by;
    const isUser = "user" in createdBy;
    const expandedCreatedBy = event.expanded?.created_by;

    let userAvatar,
      user = null;
    if (isUser) {
      userAvatar = <Image src={expandedCreatedBy.avatar} avatar />;
      user = expandedCreatedBy.full_name;
    }

    return (
      <Overridable
        id="TimelineActionEvent.layout"
        event={event}
        iconName={iconName}
        iconColor={iconColor}
      >
        <RequestsFeed.Item>
          <RequestsFeed.Content isEvent={true}>
            <RequestsFeed.Icon name={iconName} size="large" color={iconColor} />
            <RequestsFeed.Event isActionEvent={true}>
              <Feed.Label>{userAvatar}</Feed.Label>
              <Feed.Content>
                <Feed.Summary>
                  {user}{" "}
                  <TimelineEventBody
                    content={eventContent}
                    format={event?.payload?.format}
                  />
                  <Feed.Date>
                    {timestampToRelativeTime(event.created)}
                  </Feed.Date>
                </Feed.Summary>
              </Feed.Content>
            </RequestsFeed.Event>
          </RequestsFeed.Content>
        </RequestsFeed.Item>
      </Overridable>
    );
  }
}

TimelineActionEvent.propTypes = {
  event: PropTypes.object.isRequired,
  iconName: PropTypes.string.isRequired,
  eventContent: PropTypes.string.isRequired,
  iconColor: PropTypes.string,
};

TimelineActionEvent.defaultProps = {
  iconColor: "grey",
};

export default Overridable.component(
  "TimelineActionEvent",
  TimelineActionEvent
);
